@@ -1,6 +1,6 @@
 package Test::Magpie::Role::MethodCall;
 {
-  $Test::Magpie::Role::MethodCall::VERSION = '0.07';
+  $Test::Magpie::Role::MethodCall::VERSION = '0.08';
 }
 # ABSTRACT: A role that represents a method call
 use Moose::Role;
@@ -41,13 +41,14 @@ sub satisfied_by {
     my @input = $invocation->arguments;
     my @expected = $self->arguments;
     while (@input && @expected) {
-        my $matcher = shift(@expected);
+        my $matcher = shift @expected;
+
         if (ref($matcher) eq ArgumentMatcher) {
             @input = $matcher->match(@input);
         }
         else {
-            my $value = shift(@input);
-            @input = undef unless match($value, $matcher);
+            my $value = shift @input;
+            return '' if !match($value, $matcher);
         }
     }
     return @input == 0 && @expected == 0;
